@@ -457,7 +457,6 @@ ChoicePage::continueApplyDeviceChoice()
     Q_EMIT deviceChosen();
 }
 
-
 void
 ChoicePage::onActionChanged()
 {
@@ -466,6 +465,19 @@ ChoicePage::onActionChanged()
     {
         applyActionChoice( m_config->installChoice() );
     }
+
+    // Whole disk encryption isn't implemented for zfs so disable the option for now
+    if ( m_eraseFsTypesChoiceComboBox != nullptr && m_enableEncryptionWidget )
+    {
+        if ( m_eraseFsTypesChoiceComboBox->currentText() == "zfs" )
+        {
+            m_encryptWidget->hide();
+        }
+        else
+        {
+            m_encryptWidget->show();
+        }
+    }
 }
 
 void
